@@ -459,6 +459,8 @@ def evaluate_model(recording, model_folder, verbose=False):
                       (input_filename, feature_count, output_filename)
             logging.info(command)
             os.system(command)
+            # Clean up
+            os.remove(input_filename)
         elif "model" in target_folder:
             logging.info("Create running model...")
             model_src = get_latest_model(target_folder, "model")
@@ -486,6 +488,8 @@ def evaluate_model(recording, model_folder, verbose=False):
             return logfile
         else:
             logging.info("'%s' not found", target_folder)
+    # Cleanup
+    os.remove(output_filename)
 
 
 def classify_single_recording(raw_data_json, model_folder, verbose=False):
